# Auraboros

[Japanese（日本語）](./README.jp.md)

A game framework of pygame.
This project is made for me, reducing the burden of game dev using pygame.

## how to install

```:
pip install auraboros
```

## how to use CLI

```:
python -m auraboros 
```

## how to PyInstaller

Put hook-auraboros.py into hooks dir in site-packages/Pyinstaller.
